AppDialogStyle class
Constructors
- AppDialogStyle({double? width, DialogAnimationTypes animationType = DialogAnimationTypes.feedIn, Color cardColor = Colors.white, double borderRadius = 30.0, double elevation = 5.0, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.center, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, double spaceAboveMsgImg = 30.0, double spaceBelowMsgImg = 5.0, double titleHorizontalPadding = 20.0, double titleFontSize = 23.0, Color titleColor = Colors.black, TextAlign titleTextAlign = TextAlign.center, double spaceBelowTitle = 20.0, double msgHorizontalPadding = 30.0, Color msgColor = Colors.black45, double msgFontSize = 18.0, TextAlign msgTextAlign = TextAlign.center, double buttonWidth = 120.0, double? buttonHeight, Color buttonColor = Colors.white, double buttonBorderRadius = 50.0, String buttonText = 'OK', Color? buttonTextColor, double spaceBelowButton = 40.0, Widget? warningIcon, Widget? successIcon, Widget? errorIcon, Widget? infoIcon, Widget? defaultIcon})
Properties
- animationType ↔ DialogAnimationTypes
-
getter/setter pair
- borderRadius ↔ double
-
getter/setter pair
-
getter/setter pair
-
getter/setter pair
-
getter/setter pair
-
getter/setter pair
-
getter/setter pair
-
getter/setter pair
- cardColor ↔ Color
-
getter/setter pair
- crossAxisAlignment ↔ CrossAxisAlignment
-
getter/setter pair
- defaultIcon ↔ Widget?
-
getter/setter pair
- elevation ↔ double
-
getter/setter pair
- errorIcon ↔ Widget?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- infoIcon ↔ Widget?
-
getter/setter pair
- mainAxisAlignment ↔ MainAxisAlignment
-
getter/setter pair
- msgColor ↔ Color
-
getter/setter pair
- msgFontSize ↔ double
-
getter/setter pair
- msgHorizontalPadding ↔ double
-
getter/setter pair
- msgTextAlign ↔ TextAlign
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceAboveMsgImg ↔ double
-
getter/setter pair
- spaceBelowButton ↔ double
-
getter/setter pair
- spaceBelowMsgImg ↔ double
-
getter/setter pair
- spaceBelowTitle ↔ double
-
getter/setter pair
- successIcon ↔ Widget?
-
getter/setter pair
- titleColor ↔ Color
-
getter/setter pair
- titleFontSize ↔ double
-
getter/setter pair
- titleHorizontalPadding ↔ double
-
getter/setter pair
- titleTextAlign ↔ TextAlign
-
getter/setter pair
- warningIcon ↔ Widget?
-
getter/setter pair
- width ↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited