BaseController class abstract

Constructors

BaseController(State<StatefulWidget>? state, {dynamic buildContext})
base controller

Properties

busy bool
bust felid
getter/setter pair
context BuildContext
build context for the controller
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setStateFunction ↔ void Function(VoidCallback )?
the local function for setState
getter/setter pair
state State<StatefulWidget>?
the state
getter/setter pair

Methods

confirmMessage(String title, {String? message, String? imageAssert}) Future<bool>
confirm message with Yes and No buttons
dispose() → void
on dispose
hapticFeedback({bool heavy = true}) Future<void>
exec haptic feedback
navigate to other page
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setLoading() → dynamic
show loading popup
setResume([bool success = true]) → dynamic
dismiss the loading popup
setState() → dynamic
setState
showMessage(String title, MessageType type, {String heroTag = 'submit_button', String? message, String? imageAssert, String? exceptionText}) Future
show message
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited